@@ -18,7 +18,7 @@ class GridfsTest(unittest.TestCase):
 
     def setUp(self):
         super(GridfsTest, self).setUp()
-        self.db = asyncmongo.Client(pool_id='test_query', host='192.168.111.3', port=27017, dbname='gfs', mincached=3)
+        self.db = asyncmongo.Client(pool_id='test_query', host='127.0.0.1', port=27017, dbname='gfs', mincached=3)
 
 
     def test_get(self):
@@ -34,7 +34,9 @@ class GridfsTest(unittest.TestCase):
 
             fs.get(_id,noop_callback)
 
-        fs.put("78hlkjhg90ik75678", file_name = "a.png", contentType="image/png", callback = put_cb)
+        fs.put("78hlkjhg90ik75678", file_name = "a.png", contentType="image/png", 
+                                    chunk_size = 3,
+                                    callback = put_cb)
 
         #fs.list(noop_callback)
 
